# -*- coding: utf-8 -*-

#3a) A causa della ridondanza del codice genetico, la stessa proteina può 
# essere codificata da diverse sequenze di mRNA. Si sviluppi una funzione 
# check_same_prot(rna1, rna2) che restituisca True nel caso in cui le sequenze 
# di RNA descritte dalle due stringhe in ingresso codifichino la stessa 
# proteina, e False altrimenti. La funzione deve sollevare l'eccezione 
# ValueError nel caso in cui le stringhe in input non rappresentino RNA.
# Nel caso in cui il primo codone non sia un codone di start ("AUG"), si 
# supponga che esso sia implicitamente presente come codone precedente.
# Il codice genetico è disponibile sotto forma di dizionario nel 
# codice del file genetic.py (nel caso si ritenga opportuno utilizzarlo 
# in questa forma).
#
# Es. 
# rna1="AUGGCUGUAUGGCGUUAA"
# rna2="AUGGCUGUCUGGAGAUAGGUA"
# rna3="AUGGCUGUAUAUCGUUAA"
# rna4="ATGGCUGUAUAUCGUUAA"
# check_same_prot(rna1, rna2)    # -> True
# check_same_prot(rna1, rna3)    # -> False
# check_same_prot(rna2, rna3)    # -> False
# check_same_prot(rna1, rna4)    # -> ValueError


from Bio.Seq import Seq
from Bio.Alphabet import generic_rna


def check_same_prot(rna1, rna2):
    """
    Tests whether rna1 and rna2 may be translated ito the same protein sequence.
    """
    rnacodes = "AUCG"
    for c in rna1+rna2:
        if not c.upper() in rnacodes:
            raise ValueError("Only RNA seqs can be provided as input")
    r1=Seq(rna1, generic_rna)
    r2=Seq(rna2, generic_rna)
    p1=r1.translate(to_stop=True)
    p2=r2.translate(to_stop=True)
    if p1==p2:
        return True
    return False
